function varargout = Front_Panel_Quickstart(varargin)
% FRONT_PANEL_QUICKSTART M-file for Front_Panel_Quickstart.fig
%      FRONT_PANEL_QUICKSTART, by itself, creates a new FRONT_PANEL_QUICKSTART or raises the existing
%      singleton*.
%
%      H = FRONT_PANEL_QUICKSTART returns the handle to a new FRONT_PANEL_QUICKSTART or the handle to
%      the existing singleton*.
%
%      FRONT_PANEL_QUICKSTART('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in FRONT_PANEL_QUICKSTART.M with the given input arguments.
%
%      FRONT_PANEL_QUICKSTART('Property','Value',...) creates a new FRONT_PANEL_QUICKSTART or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Front_Panel_Quickstart_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Front_Panel_Quickstart_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help Front_Panel_Quickstart

% Last Modified by GUIDE v2.5 21-May-2006 22:27:47

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Front_Panel_Quickstart_OpeningFcn, ...
                   'gui_OutputFcn',  @Front_Panel_Quickstart_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Front_Panel_Quickstart is made visible.
function Front_Panel_Quickstart_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Front_Panel_Quickstart (see VARARGIN)

% Choose default command line output for Front_Panel_Quickstart
handles.output = hObject;
%Display the Diagram of the front Panel
[X,map] = imread('Front_Panel_Demo', 'bmp');
axes(handles.axes1);
image(X)
colormap(map);
%remove the tickmarks
set(handles.axes1, 'XTick', [], 'YTick', [])

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Front_Panel_Quickstart wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Front_Panel_Quickstart_OutputFcn(hObject, eventdata, handles) 

varargout{1} = handles.output;


% --- Executes on selection change in listbox1.
function listbox1_Callback(hObject, eventdata, handles)

% --- Executes during object creation, after setting all properties.
function listbox1_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes on button press in Close.
function Close_Callback(hObject, eventdata, handles)
delete(gcf)


